//----------------------------------------------------------------------
// Best viewed with tabs every 4 columns
//----------------------------------------------------------------------

import java.util.*;

/**
 * CantMove - This program determines the winner in a stone removal
 * game.
 *
 * In the can't-move game there are two players, P1 and P2. They share a
 * common pile of stones, and each starts with a designated maximum
 * number of stones that this player may remove. The players alternate
 * turns, with Player 1 starting. With each turn a player can remove
 * either one or two stones from the pile. A player loses when it is
 * this player's turn and either the stone pile is empty or the player
 * has exhausted his/her allocation of stones to remove.
 *
 * Given an input configuration, consisting of the initial number of
 * stones, the number of stones player 1 can take, and the number of 
 * stones player 2 can take, the program determines which player has a 
 * winning strategy.
 */
public class CantMove {

	/** 
	 *  Main Program - Reads the input and outputs the final answer.
	 */
	public static void main(String[] args) throws Exception {
		Scanner scanner = new Scanner(System.in);
		int numTrials = scanner.nextInt();	// number of trials to run

		for(int t = 1; t <= numTrials; t++) {
			int nStones = scanner.nextInt();// initial number of stones
			int nTake1 = scanner.nextInt();	// number of stones P1 may take
			int nTake2 = scanner.nextInt();	// number of stones P2 may take

			System.out.println("Trial " + t + ":\n" +
					"  " + nStones + " stones\n" +
					"  up to " + nTake1 + " stones may be taken by P1 in total\n" +
					"  up to " + nTake2 + " stones may be taken by P2 in total\n");

											// input sanity check
			if (nStones < 0 || nTake1 < 0 || nTake2 < 0) {
				System.out.println("Error: Inputs must be nonnegative");
				scanner.close();
				return;
			}
			if (nStones > 1000 || nTake1 > nStones || nTake2 > nStones) {
				System.out.println("Warning: Inputs beyond reasonable limits");
			}

											// determine the winner
			int winner = getWinner(nStones, nTake1, nTake2);

											// print the output
			if (winner == 1 || winner == 2) {
				System.out.println("Player P" + winner + " wins");
			}
			else {
				System.out.println("Error - The answer must be either 1 or 2");
			}
			System.out.println();
		}
		scanner.close();					// close input stream
	}

	private static int getWinner(int nStones, int nTake1, int nTake2) {

		/* -------------------- INSERT CODE HERE ----------------------*/

		/* --------------------- HOW IT WORKS --------------------------
		 * The solution is based on dynamic programming. Define:
		 *
		 * 		W[p, s, t1, t2]
		 *
		 * to be the winner assuming that player p starts first given a
		 * starting configuration with s stones, P1 can take t1 stones,
		 * and P2 can take t2 stones.
		 *
		 * We compute W inductively as follows. Let's consider the case
		 * where player 1 starts. (The other case is symmetrical.)
		 * If s >= 1 and t1 >= 1, then P1 attempts to take one stone.
		 * This results in a game where P2 plays first, has s-1 stones in
		 * the pile, and where P1 has t1-1 takes remaining, and P2 has
		 * t2 takes remaining. Thus, if
		 *
		 * 		s >= 1 && t1 >= 1 && W[2, s-1, t1-1, t2] == 1
		 *
		 * then P1 can force a win, and selects this move. If s >= 2 and
		 * t1 >= 2, then P1 attempts to take two stones. This results in
		 * a game where P2 plays first, has s-2 stones in the pile, and
		 * where P1 has t1-2 takes remaining, and P2 has t2 takes
		 * remaining. Thus, if
		 *
		 * 		s >= 2 && t1 >= 2 && W[2, s-2, t1-2, t2] == 1
		 *
		 * then P1 can again force a win, and selects this move.
		 * Otherwise, P2 can force a win no matter which choice P1
		 * makes. (This includes the case where s == 0 or t1 == 0, in
		 * which case P1 loses immediately because he can't move.)
		 *
		 * In summary, we have:
		 *
		 * 		W[1, s, t1, t2] = 1 if either:
		 *
		 * 			s >= 1 && t1 >= 1 && W[2, s-1, t1-1, t2] == 1
		 *
		 * 			-- or --
		 *
		 * 			s >= 2 && t1 >= 2 && W[2, s-2, t1-2, t2] == 1
		 *
		 * 		and otherwise
		 *
		 * 		W[1, s, t1, t2] = 2
		 *
		 * The cases for W[2, *, *, *] are symmetrical, but with the
		 * roles of P1 and P2 reversed.
		 *
		 * Note: We have chosen to compute W iteratively. We could have
		 * also computed it by means of a recursive function, but we
		 * need to be careful to avoid making duplicate calls with the
		 * same parameter values, for otherwise the running time will
		 * grow too quickly. This can be done through memoization. The
		 * values are computed recursively, but they are saved in an
		 * array to avoid repeated computation of the same values.
		 *
		 */

										// allocate the array
		int[][][][] W = new int [3][nStones + 1][nTake1 + 1][nTake2 + 1];
										// initialize it
		for (int s = 0; s <= nStones; s++) {
			for (int t1 = 0; t1 <= nTake1; t1++) {
				for (int t2 = 0; t2 <= nTake2; t2++) {
										// player 1
					if ((s >= 1 && t1 >= 1 && W[2][s-1][t1-1][t2] == 1) ||
						(s >= 2 && t1 >= 2 && W[2][s-2][t1-2][t2] == 1))
					{
						W[1][s][t1][t2] = 1;
					}
					else
					{
						W[1][s][t1][t2] = 2;
					}
										// player 2
					if ((s >= 1 && t2 >= 1 && W[1][s-1][t1][t2-1] == 2) ||
						(s >= 2 && t2 >= 2 && W[1][s-2][t1][t2-2] == 2))
					{
						W[2][s][t1][t2] = 2;
					}
					else
					{
						W[2][s][t1][t2] = 1;
					}
				}
			}
		}
										// final winner
		int winner = W[1][nStones][nTake1][nTake2];
		return winner;
		/* --------------------- END OF INSERTION ---------------------*/
	}

}
