//----------------------------------------------------------------------
// Best viewed with tabs every 4 columns
//----------------------------------------------------------------------

import java.util.*;

/** ExamGuessing - Determines how many questions to guess at on an exam.
 *
 * There are n questions on an exam, and let C and W be two positive
 * integers.
 *
 *  - If an answer is given and it is correct, we receive C points.
 *
 *  - If an answer is given and it is incorrect, we lose W points.
 *
 *  - If a question is left blank, we receive 0 points.
 *
 * Our teacher does not want any negative scores, so every student will
 * receive a score of at least zero. Thus, if we answer i out of n
 * questions correctly, our score will be:
 *
 *		max(0, i * C - (n-i) * W)
 *
 * We are given an array of probabilities, p[0], ..., p[n-1], where p[i]
 * is the probability that our answer for the i-th exam question is
 * correct. The computational problem is this: Which questions should we
 * attempt to answer in order to maximize the expected score on the
 * exam?
 *
 * Provide the body for the function whichToAttempt below. The
 * function's output is in the form of the boolean array attempt, where
 * attempt[i] is true if we determine that we should attempt the i-th
 * question.
 *
 * To make the problem a bit easier to solve efficiently, we are told
 * that there will be only five possible probability values: 1/4, 1/2,
 * 3/4, and 1. (The solution can either take advantage of this fact or
 * ignore it.)
 *
 */
public class ExamGuessing {

	/** 
	 *  Main Program - Reads the input and outputs the final answer.
	 */
	public static void main(String[] args) throws Exception {
		Scanner scanner = new Scanner(System.in);
		int numTrials = scanner.nextInt();	// number of trials to run

		for(int t = 1; t <= numTrials; t++) {
			int n = scanner.nextInt();		// number of questions
			int C = scanner.nextInt();		// points for correct answer
			int W = scanner.nextInt();		// penalty for incorrect answer
			double[] p = new double[n];		// probabilities

			for (int i = 0; i < n; i++) {	// input the probabilities
				p[i] = scanner.nextDouble();
											// check
				if (p[i] != 0.25 && p[i] != 0.50 && p[i] != 0.75 && p[i] != 1.00) {
					System.out.println("Error - Invalid probability value");
					scanner.close();
					return;
				}
			}

											// the questions to attempt
			boolean[] attempt = new boolean[n];

			for (int i = 0; i < n; i++) {	// initialize
				attempt[i] = false;
			}
											// summarize input
			System.out.println("Trial " + t + ":\n" +
					"  " + n + " questions\n" +
					"  " + C + " points for correct answers\n" +
					"  " + W + " point deduction for incorrect answers\n");

											// determine which to try
			double maxExpScore = whichToAttempt(n, C, W, p, attempt);
											// output results
			System.out.println("  Maximum expected score = " + maxExpScore);

			for (int i = 0; i < n; i++) {
				System.out.print("  Prob[" + i + "] = " + p[i] + "  ---  ");
				if (attempt[i]) 
				{
					System.out.println("attempt");
				}
				else
				{
					System.out.println("skip");
				}
			}
			System.out.println();
		}
		scanner.close();					// close input stream
	}

	private static double whichToAttempt(int n, int C, int W, double[] p, boolean[] attempt) {

		/* -------------------- INSERT CODE HERE ----------------------*/

		/* --------------------- HOW IT WORKS --------------------------
		 * Our solution will not make use of the fact that there are
		 * only a limited number of distinct probabilities. We will make
		 * use of the obvious fact that in any guessing system, if k
		 * questions are to be guessed at, they should be the k
		 * questions with the k highest probabilities.  To facilitate
		 * this, we first sort the questions in decreasing order of
		 * probabilities.  (Since Java indices start at 0, these will be
		 * questions indexed 0 through k-1.)
		 *
		 * Our approach will be to enumerate all the possible values of
		 * k from 0 up to n. (Setting k to zero will never be useful
		 * since it guarantees a score of zero, but it makes the
		 * induction a bit cleaner.)
		 *
		 * If we attempt k questions and get i of them correct, then
		 * (because the remaining n-k are left blank) our total score
		 * will be
		 *
		 *		score(i,k) = max(0, i * C - (k-i) * W).
		 *
		 * Given a candidate value of k, for each i running from 0 to k,
		 * we will compute the exact probability of giving a correct
		 * answer to the first i of these k questions and an incorrect
		 * answer to the remaining k-i. Let us call this probability of
		 * correctness PC[i,k]. Assuming for now that we can compute PC
		 * for all values of i and k, our expected score will be the
		 * weighted sum of all the possible outcomes:
		 *
		 *		E(score(k)) = Sum_{i=0}^k PC[i,k] * score(i,k).
		 *
		 * We determine the value of k, call it k*, that maximizes this
		 * quantity. The final answer will be to attempt the questions
		 * with the k* highest probabilities and skip all the rest.
		 *
		 * All that remains to explain is how to compute PC[i,k]. We
		 * will do this inductively, based on the value of k. Let p[0],
		 * ..., p[k-1] denote the k largest probabilities in decreasing
		 * sorted order. For the sake of simplifying notation, define
		 * q[i] = 1 - p[i], to be the probability of answering question
		 * i incorrectly.
		 *
		 * For the basis case (k=0), we have zero questions and so we
		 * are guaranteed to get zero correct. Thus we have
		 *
		 *		PC[0,0] = 1.
		 *
		 * For the induction, let us assume that we have already
		 * computed PC[*,k-1], and we wish to compute PC[*,k]. There are
		 * two ways that we can obtain i correct answers with k
		 * questions:
		 *
		 * - We already had i-1 correct answers from the first k-1
		 *   questions, and then we answered the last question
		 *   correctly. This occurs with probability PC[i-1,k-1] *
		 *   p[k-1].
		 *
		 * - We already had i correct answers from the first k-1
		 *   questions, and then we answered the last question
		 *   incorrectly. This occurs with probability PC[i, k-1] *
		 *   q[k-1].
		 *
		 * Thus, for i running from 0 to k, we have
		 *
		 *		PC[i,k] = PC[i-1,k-1] * p[k-1] + PC[i, k-1] * q[k-1]
		 * 
		 * (Note that when i = 0 and i = k, one of the two terms above
		 * is not defined, and so we ignore its contribution.)
		 *
		 */

		int[] perm = new int[n];		// permutation array

		sortAndGetPermutation(p, perm);	// sort in descending order
										// p[i] is now in p[perm[i]]
										// probability of getting i out of k
		double[][] PC = new double[n+1][n+1];
										// expected score for k guesses
		double[] expScore = new double[n+1];

		double maxExpScore = 0;			// maximum expected score
		int maxK = 0;					// number to guess for maxExpScore
		PC[0][0] = 1;					// basis case - zero out of zero
		for (int k = 1; k <= n; k++) {	// try to guess k questions
			double pk = p[perm[k-1]];	// probability of correct guess
			double qk = 1 - pk;			// probability of incorrect guess
										// compute probability of i correct
			for (int i = 0; i <= k; i++) { 
				PC[i][k] = 0.0;
				if (i > 0) {			// one more correct guess
					PC[i][k] += PC[i-1][k-1] * pk;
				}
				if (i < k) {			// one more incorrect guess
					PC[i][k] += PC[i][k-1] * qk;
				}
			}
		}

		for (int k = 0; k <= n; k++) {	// computed expected score
			expScore[k] = 0;			// get expected score from k guesses
			for (int i = 0; i <= k; i++) {
				expScore[k] += PC[i][k] * score(i, k, C, W);
			}

										// best so far?
			if (expScore[k] > maxExpScore) {
				maxExpScore = expScore[k];
				maxK = k;
			}
		}

										// finally, guess at the top k
		for (int i = 0; i < n; i++) {
			if (i < maxK) {
				attempt[perm[i]] = true;
			}
			else {
				attempt[perm[i]] = false;
			}
		}

		return maxExpScore;				// return max expected score
	}

	/** Return score assuming i correct out of k guessed.
	 * 
	 */
	private static int score(int i, int k, int C, int W) {
		int rawScore = i * C - (k-i) * W;
		if (rawScore < 0) {
			return 0;
		}
		else {
			return rawScore;
		}
	}

	/** sortAndGetPermutation
	 *
	 * Descending sort yielding a permutation array. This sorts an array
	 * in descending order, but rather than permuting the elements, it
	 * modifies the array perm so that perm[i] is the position of the
	 * ith smallest elements of the array. We do this by selection sort,
	 * repeatedly copying the largest remaining element and keeping
	 * track of the element we just removed.
	 */
	private static void sortAndGetPermutation(double[] p, int[] perm) {
		int n = p.length;				// length of p (and perm)
		double[] pp = new double[n];	// sorted elements copied here
		boolean[] taken = new boolean[n]; // this element moved to pp

		for (int i = 0; i < n; i++) {	// initialize taken
			taken[i] = false;
		}

		for (int i = 0; i < n; i++) {	// selection sort
			double pMax = -1;			// stores the maximum element
			int jMax = -1;				// stores its index in p
			for (int j = 0; j < n; j++) { // get maximum remaining
				if (!taken[j] && p[j] > pMax) {
					pMax = p[j];		// save new max
					jMax = j;
				}
			}
			pp[i] = pMax;				// copy to pp
			perm[i] = jMax;				// remember its position
			taken[jMax] = true;			// this element is now taken
		}

		/* --------------------- END OF INSERTION ---------------------*/
	}

}
